dnl # 6.2-rc1 API change
dnl # https://lwn.net/Articles/917733/
dnl #
dnl # timer_shutdown() and timer_shutdown_sync() are meant to ease the task of
dnl # cleaning up timers that might be rearmed during that process; once they
dnl # are called, any attempts to rearm the timer will be ignored.
dnl #
AC_DEFUN([ZFS_AC_KERNEL_TIMER_SHUTDOWN], [
	AC_MSG_CHECKING([whether timer_shutdown exists])
	ZFS_CHECK_SYMBOL_EXPORT([timer_shutdown], [], [
		have_timer_shutdown=yes
		AC_MSG_RESULT(yes)
	], [
		have_timer_shutdown=no
		AC_MSG_RESULT(no)
	])

	AC_MSG_CHECKING([whether timer_shutdown_sync exists])
	ZFS_CHECK_SYMBOL_EXPORT([timer_shutdown_sync], [], [
		have_timer_shutdown_sync=yes
		AC_MSG_RESULT(yes)
	], [
		have_timer_shutdown_sync=no
		AC_MSG_RESULT(no)
	])

	AS_IF([test "x$have_timer_shutdown$have_timer_shutdown_sync" = "xyesyes"], [
		AC_DEFINE(BACKPORT_HAVE_TIMER_SHUTDOWN, 1,
			[timer_shutdown/timer_shutdown_sync exists])
	], [
		AS_IF([test "x$have_timer_shutdown$have_timer_shutdown_sync" = "xnono"], [], [
			AC_MSG_ERROR([
	*** Expected to define or undefine timer_shutdown and timer_shutdown_sync
	*** at the same time, but got otherwise.
			])
		])
	])
])

dnl # 6.2-rc1 API change
dnl # https://lwn.net/Articles/917733/
dnl #
dnl # del_timer() and del_timer_sync() have been renamed to timer_delete() and
dnl # timer_delete_sync() respectively.
dnl #
AC_DEFUN([ZFS_AC_KERNEL_TIMER_DELETE_SYNC], [
	AC_MSG_CHECKING([whether timer_delete_sync exists])
	ZFS_CHECK_SYMBOL_EXPORT([timer_delete_sync], [], [
		AC_MSG_RESULT(yes)

		AC_DEFINE(BACKPORT_HAVE_TIMER_DELETE_SYNC, 1,
			[timer_delete_sync exists])
	], [
		AC_MSG_RESULT(no)
	])
])
